=============================
The History of Plone Intranet
=============================

.. admonition:: Description

    This document gives a short overview of the historical genesis of this project. For the current status, see the Quaive_ website.

The Plone Intranet project started life as a discussion between Netsight and Cosent back in 2013. Like a number of Plone companies, Netsight had already been working on intranet projects for some years, starting with a bespoke intranet for Belron in 2007. In more recent years Netsight saw the need to componentise their offering to improve manageability of the codebase, to make supporting their solutions easier, and to help remain competitive in the marketplace (re-selling existing code was becoming a necessity).

The idea behind this project is to build upon a number of existing packages out there in the Plone world that provide intranet-like functionality. Over the years many products have been developed, often inside individual organisations, with much repetition.

At the 2013 Plone Conference an open space session indicated that there were a number of other Plone companies with a similar history to Netsight’s in the intranet marketplace. With the growth of the intranet/digital workplace industry, it became clear that a number of Plone companies saw an opportunity to commercialise on a common Plone-based intranet solution. These discussions continued with other Plone community members which lead to the organisation of the first Plone Intranet summit in November 2013, and the formation of the Plone Intranet Consortium, which was later renamed into Quaive_.

An in-person meeting was arranged to follow up and brainstorm on these ideas two weeks after the conference.
For expediency, those invited were those we knew who had an interest and experience with Plone intranets and who
were located within an hour of London.

This initial meeting was held in London and attended by:

* Matt Hamilton, Matthew Sital-Singh, Ben Ackland - Netsight (UK)
* Guido Stevens - Cosent (NL)
* Alexander Pilz - Syslab (DE)
* Rob Gietema - Four Digits (NL)
* Philip Bauer - Starzel (DE) (remote)
* Bernharn Bühlmann - 4Teamwork (CH) (remote)

A number of key areas were identified which are common requirements for intranets and which have been
repeatedly over and over by a number of similar Plone add-ons.

Following a number of weekly Hangout sessions with the participants, a number of user stories were collected and organised
into a `spreadsheet <https://docs.google.com/spreadsheet/ccc?key=0AmooreRUAv9PdGg4eG5VWkxZVS1EaWdCQllWWnh1Snc&usp=sharing>`_.

In early 2014, Netsight received funding to research social software within the enterprise. This grant has been used to research new process methodologies to improve the success rate of the introduction of social technologies into the organisation environment. In particular, Netsight have focussed on profiling individuals, departments and an entire organisation in order to deliver relevant social content and user interface within an intranet system.

In October 2014, the Plone Intranet Consortium met in Munich and decided on a concrete commitment to developing Plone Intranet by investing money and manpower. Development was organised using Scrum and a roadmap for a first version was set.

In October 2015, the Plone Intranet Consortium was renamed into Quaive and the first production version of the software suite was released.

The founding partners of Quaive are:

* Netsight (UK)
* Cosent (Netherlands)
* Syslab (Germany)
* FourDigits (Netherlands)
* Abstract (Italy)
* Red Turtle (Italy)
* Starzel (Germany)
* Zest (Netherlands)

Important Aspects of Plone Intranet
-----------------------------------

* Design First
* Roadmap-driven Scrum development
* Quaive board funds roadmap
* 100% Open Source - all code is donated to the Plone Foundation
* NOT a core fork
* Compatible with mockup
* NOT a €€€ conspiracy
* Plone 5 based


Further reading
---------------

* The study `Systems of Intent <http://cosent.nl/roadmap>`_ created by Guido Stevens
* The Talk given at the Plone Conference 2014 in Bristol

    * Slides at `Slideshare <http://www.slideshare.net/GuidoStevens/plone-intranet-consortium-united-we-stand-divided-we-fall>`_
    * Video at `Vimeo <http://vimeo.com/110489988>`_

* Many talks given at the Plone Conference 2015 in Bucharest, see the `ploneintranet tweet stream`_      

.. _Quaive: http://quaive.com
.. _ploneintranet tweet stream: https://twitter.com/ploneintranet
